ContractVerificationDal

Struct ContractVerificationDal 

pub struct ContractVerificationDal<'a, 'c> { /* private fields */ }

Implementations

Source

impl ContractVerificationDal<'_, '_>

pub async fn get_count_of_queued_verification_requests( &mut self, ) -> Result<usize>

pub async fn add_contract_verification_request( &mut self, query: VerificationIncomingRequest, ) -> Result<usize>

pub async fn get_next_queued_verification_request( &mut self, processing_timeout: Duration, ) -> Result<Option<VerificationRequest>>

Returns the next verification request for processing. Considering the situation where processing of some request can be interrupted (panic, pod restart, etc..), processing_timeout parameter is added to avoid stuck requests.

pub async fn save_verification_info( &mut self, verification_info: VerificationInfo, ) -> Result<()>

Updates the verification request status and inserts the verification info upon successful verification.

pub async fn save_verification_error( &mut self, id: usize, error: String, compilation_errors: Value, panic_message: Option<String>, ) -> Result<()>

pub async fn get_verification_request_status( &mut self, id: usize, ) -> Result<Option<VerificationRequestStatus>>

pub async fn get_contract_info_for_verification( &mut self, address: Address, ) -> Result<Option<(Vec<u8>, DeployContractCalldata)>>

Returns bytecode and calldata from the contract and the transaction that created it.

pub async fn is_contract_verified(&mut self, address: Address) -> Result<bool>

Returns true if the contract has a stored contracts_verification_info.

pub async fn get_zksolc_versions(&mut self) -> Result<Vec<String>>

pub async fn get_solc_versions(&mut self) -> Result<Vec<String>>

pub async fn get_zkvyper_versions(&mut self) -> Result<Vec<String>>

pub async fn get_vyper_versions(&mut self) -> Result<Vec<String>>

pub async fn set_zksolc_versions(&mut self, versions: Vec<String>) -> Result<()>

pub async fn set_solc_versions(&mut self, versions: Vec<String>) -> Result<()>

pub async fn set_zkvyper_versions( &mut self, versions: Vec<String>, ) -> Result<()>

pub async fn set_vyper_versions(&mut self, versions: Vec<String>) -> Result<()>

pub async fn get_all_successful_requests( &mut self, ) -> Result<Vec<VerificationRequest>>

pub async fn get_contract_verification_info( &mut self, address: Address, ) -> Result<Option<VerificationInfo>>